//
//  Module      : mailqueue.cpp
//  Author      : Oren Sokoler 
//  E-mail      : orenskl@netvision.net.il
//  Description : This module is the mail queue widget
//
//  Copyright (C) 1999 Oren Sokoler
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

//-----------------------------------------------------
//                qtmail include files
//-----------------------------------------------------

#include "mailqueue.h"
#include "queuefile.h"

//-----------------------------------------------------
//	        Methods of class MailQueue
//-----------------------------------------------------

// Method      : MailQueue
// Description : MailQueue constructor
// Parameters  : QParent  - This widget's parent widget
//               MailQDir - Mail queue directory
//               Time     - Update interval
// Returns     : none.
// Notes       : none.
MailQueue::MailQueue(QWidget *parent , const char *MailQDir,int Time) : QWidget(parent)  
{
  // Setup mail queue List

  List = new QListView(this,"List");

  List->addColumn("Message ID",90);
  List->addColumn("From",(List->width()-90) / 2);
  List->addColumn("To",List->width() - 90 - ((List->width()-90) / 2));

  if (MailQDir)
    MailDir = MailQDir;
  else
    MailDir = "/var/spool/mqueue";

  // Setup inital queue

  timerEvent(0);

  // Start the timer event
 
  startTimer(Time * 1000);
}

// Method      : ~MailQueue
// Description : MailQueue destructor
// Parameters  : none.
// Returns     : none.
// Notes       : none.
MailQueue::~MailQueue(void)
{
  delete List;
}

// Method      : resizeEvent
// Description : Resize event for mail queue
// Parameters  : QResizeEvent - Qt resize event
// Returns     : none.
// Notes       : none.
void MailQueue::resizeEvent( QResizeEvent * )
{
  List->resize( width()  , height() );
  List->setColumnWidth(0,90);
  List->setColumnWidth(1,(List->width()-90) / 2);
  List->setColumnWidth(2,List->width() - 90 - ((List->width()-90) / 2));  
}

// Method      : setFont
// Description : Sets the font for all the mail queue text
// Parameters  : MailFont - Mail queue font
// Returns     : none.
// Notes       : none.
void MailQueue::setFont( const QFont & MailFont)
{
  List->setFont(MailFont);
}

// Method      : timerEvent
// Description : timer event from Qt
// Parameters  : QTimerEvent - Qt event
// Returns     : none.
// Notes       : none.
void MailQueue::timerEvent( QTimerEvent * )
{
  // Clear list
  List->clear();
  MsgData.clear();

  // Scan mail directory

  QDir     * TmpMailDir  = new QDir(MailDir,"q*");
  QStrList * FileList    = (QStrList *)TmpMailDir->entryList();  
  QString    AbsFileName;

  char * Name = FileList->first();
  while (Name) {
    // Create absolute file name
    AbsFileName = MailDir;
    AbsFileName.append("/");
    AbsFileName.append(Name);
    // Get queue file info
    QueueFile * MyQFile = new QueueFile((const char *)AbsFileName);
    MsgData.append(new QListViewItem (List,&Name[2],MyQFile->From(),MyQFile->To()));
    delete MyQFile;
    Name   = FileList->next();
  }

  delete TmpMailDir;  
}
